import 'package:flutter/material.dart';

import 'BlinkingAnimation.dart';
import 'BlinkingWidget.dart';

class BlinkingWidget2 extends StatefulWidget {
  /// Creates a [BlinkingWidget2] widget
  BlinkingWidget2({
    Key? key,
    this.beginColor,
    this.endColor,
    this.duration,
    this.repeats,
    required this.builder,
    this.disabled = false,
  }) : super(key: key);

  final ColoredWidgetBuilder builder;

  /// Duration of blinking animation, default is 1 second.
  final Duration? duration;

  /// Times to repeat color animation. [null] is infinite, 0 is without animation.
  final int? repeats;

  /// Starting color, default value is [Colors.black].
  final Color? beginColor;

  /// End color, default value is [Colors.transparent].
  final Color? endColor;

  // Disable animation. Build widget only once with beginColor.
  final bool disabled;

  @override
  BlinkingWidget2State createState() => BlinkingWidget2State();
}

class BlinkingWidget2State extends State<BlinkingWidget2> with TickerProviderStateMixin {
  BlinkingAnimation? blinkingAnimation;

  @override
  void initState() {
    blinkingAnimation?.dispose();
    blinkingAnimation = BlinkingAnimation(
      vsync: this,
      beginColor: widget.beginColor,
      disabled: widget.disabled,
      duration: widget.duration,
      endColor: widget.endColor,
      repeats: widget.repeats,
    );
    super.initState();
  }

  @override
  void didUpdateWidget(covariant BlinkingWidget2 oldWidget) {
    super.didUpdateWidget(oldWidget);

    if (widget.disabled != oldWidget.disabled ||
        widget.repeats != oldWidget.repeats ||
        widget.endColor != oldWidget.endColor ||
        widget.duration != oldWidget.duration) {
      blinkingAnimation!.setDisabled(widget.disabled);
      blinkingAnimation!.setEndColor(widget.endColor);
      blinkingAnimation!.setRepeats(widget.repeats);
      blinkingAnimation!.setDuration(widget.duration);
    }
  }

  // void _initializeController() {
  //   print('_initializeController');
  //   blinkingAnimation = BlinkingAnimation(
  //     vsync: this,
  //     beginColor: widget.beginColor,
  //     disabled: widget.disabled,
  //     duration: widget.duration,
  //     endColor: widget.endColor,
  //     repeats: widget.repeats,
  //   );
  // }

  @override
  void dispose() {
    blinkingAnimation?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final builder = widget.builder;

    // return ChangeNotifierProvider.value(
    //   value: blinkingAnimation,
    //   builder: (context, child) {
    // return builder(context, blinkingAnimation!.color);
    return AnimatedBuilder(
      animation: blinkingAnimation!,
      builder: (context, child) => builder(context, blinkingAnimation!.color),
    );
    //   },
    // );
    // if (controller == null || disabled == true) {
    //   return widget.builder(context, beginColor);
    // } else {
    //   return AnimatedBuilder(
    //     animation: controller!,
    //     builder: (context, child) => widget.builder(context, colorAnimation.value!),
    //   );
    // }
  }
}
