import 'package:flutter/widgets.dart';
import 'package:provider/provider.dart';
import 'package:provider/single_child_widget.dart';

class ChangeNotifierConsumer<T extends ChangeNotifier?> extends SingleChildStatelessWidget {
  /// {@template provider.consumer.constructor}
  /// Consumes a [Provider<T>]
  /// {@endtemplate}
  ChangeNotifierConsumer({
    Key? key,
    required this.builder,
    required this.provider,
    Widget? child,
  }) : super(key: key, child: child);

  /// {@template provider.consumer.builder}
  /// Build a widget tree based on the value from a [Provider<T>].
  ///
  /// Must not be `null`.
  /// {@endtemplate}
  final Widget Function(
    BuildContext context,
    T value,
    Widget? child,
  ) builder;

  final T provider;

  @override
  Widget buildWithChild(BuildContext context, Widget? child) {
    return ChangeNotifierProvider<T>.value(
      value: provider,
      child: Consumer<T>(builder: builder),
    );
    // return builder(
    //   context,
    //   Provider.of<T>(context),
    //   child,
    // );
  }
}