import 'package:flutter/material.dart';

import 'chip_list_controller.dart';
import 'chip_list_item.dart';

class ChipList extends StatelessWidget {
  ChipList({
    Key? key,
    List<ChipListItem>? items,
    ChipListController? controller,
    this.onAddPressed,
  })  : assert(
          items == null || controller == null,
          'Use controller constructor to provide intital items.',
        ),
        controller = controller ?? ChipListController(items: items),
        super(key: key);

  final ChipListController controller;
  final VoidCallback? onAddPressed;

  @override
  Widget build(BuildContext context) {
    final borderColor = Theme.of(context).colorScheme.secondary;

    return AnimatedBuilder(
      animation: controller,
      builder: (context, _) {
        return Wrap(
          runSpacing: 8,
          spacing: 8,
          children: [
            if (onAddPressed != null)
              ActionChip(
                label: Text('Neu'),
                onPressed: onAddPressed!,
                // onPressed: () async {

                avatar: Icon(Icons.add),
              ),
            ...controller.items.map(
              (e) {
                final leftPadding = e.icon == null ? 16.0 : 4.0;
                final rightPadding = e.canDelete == true ? 4.0 : 16.0;

                return InputChip(
                  backgroundColor: Colors.transparent,
                  shape: StadiumBorder(
                    side: BorderSide(width: 0.0, color: borderColor),
                  ),
                  padding: EdgeInsets.all(0.0),
                  avatar: e.icon == null
                      ? null
                      : CircleAvatar(
                          child: e.icon,
                          backgroundColor: Colors.transparent,
                        ),
                  label: Text(e.text),
                  labelPadding: EdgeInsets.only(left: leftPadding, right: rightPadding),
                  visualDensity: VisualDensity.compact,
                  deleteIconColor: e.removeFlag == true ? Colors.red.shade400 : null,
                  selectedColor: Colors.transparent,
                  onSelected: (_) => controller.clearRemoveFlags(),
                  onDeleted: e.canDelete == false ? null : () => controller.shoudRemove(e),
                );
              },
            ).toList()
          ],
        );
      },
    );
  }
}
