import 'package:flutter/material.dart';

import 'color_descriptor.dart';
import 'color_tab_view.dart';
import 'color_table.dart';

Future<ColorDescriptor?> showColorSelectorPage(BuildContext context) async {
  return Navigator.of(context).push(
    MaterialPageRoute(
      builder: (context) {
        return ColorSelectorPage(
          // onTap: (value) => selectedColor = value,
          onDoubleTap: (value) => _close(context, value),
        );
      },
    ),
  );
}

void _close(BuildContext context, ColorDescriptor? selectedColor) {
  Navigator.of(context).pop(selectedColor);
}

class ColorSelectorPage extends StatefulWidget {
  const ColorSelectorPage({
    Key? key,
    this.onDoubleTap,
    this.onTap,
  }) : super(key: key);

  final ValueSetter<ColorDescriptor>? onTap;
  final ValueSetter<ColorDescriptor>? onDoubleTap;

  @override
  _ColorSelectorPageState createState() => _ColorSelectorPageState();
}

class _ColorSelectorPageState extends State<ColorSelectorPage> {
  ColorDescriptor? selectedColor;

  @override
  Widget build(BuildContext context) {
    final allColors = ColorTable().palettes;

    return DefaultTabController(
      length: allColors.length,
      child: Scaffold(
        appBar: AppBar(
          actions: [
            IconButton(
              onPressed: () {
                widget.onDoubleTap?.call(selectedColor!);
              },
              icon: Icon(Icons.done),
            ),
          ],
          automaticallyImplyLeading: true,
          title: Text('Farben'),
          bottom: TabBar(
            isScrollable: true,
            // indicator: UnderlineTabIndicator(),
            tabs: [
              for (final palette in allColors) Tab(text: palette.title),
            ],
          ),
        ),
        body: TabBarView(
          children: [
            for (final palette in allColors)
              Material(
                color: palette.colorName == 'white'
                    ? Colors.black
                    : palette.colorName == 'black'
                        ? Colors.white
                        : Colors.transparent,
                child: ColorTabView(
                  colorPalette: palette,
                  onTap: (value) {
                    selectedColor = value;
                    widget.onTap?.call(value);
                  },
                  onDoubleTap: widget.onDoubleTap,
                ),
              ),
          ],
        ),
      ),
    );
  }
}
