import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

T toEnum<T>(List values, String key, Map<String, dynamic> map) {
  return values.firstWhere((element) => describeEnum(element) == map[key]);
}

extension SizeExtension on Size {
  Map<String, Object> toMap() {
    return {
      'width': width,
      'height': height,
    };
  }

  static Size fromMap(Map<String, Object> map) {
    return Size(double.parse(map['width'].toString()), double.parse(map['height'].toString()));
  }
}

extension EdgeInsetsExtension on EdgeInsets {
  Map<String, Object> toMap() {
    return {
      'left': left,
      'top': top,
      'right': right,
      'bottom': bottom,
    };
  }

  static EdgeInsets fromMap(Map<String, Object> map) {
    return EdgeInsets.fromLTRB(
      double.parse(map['left'].toString()),
      double.parse(map['top'].toString()),
      double.parse(map['right'].toString()),
      double.parse(map['bottom'].toString()),
    );
  }
}

extension TargetPlatformExtension on TargetPlatform {
  Map<String, Object> toMap() {
    return {
      'targetPlatform': describeEnum(this),
    };
  }

  static TargetPlatform fromMap(Map<String, Object> map) {
    return toEnum<TargetPlatform>(TargetPlatform.values, 'targetPlatform', map);
  }
}

extension DurationExtension on Duration {
  Map<String, Object> toMap() {
    return {
      'duration': inMicroseconds,
    };
  }

  static Duration fromMap(Map<String, Object> map) {
    final duration = int.parse(map['duration'].toString());
    return Duration(microseconds: duration);
  }
}

extension OrientationExtension on Orientation {
  Map<String, Object> toMap() {
    return {
      'orientation': describeEnum(this),
    };
  }

  static Orientation fromMap(Map<String, Object> map) {
    // return Orientation.values[int.parse(map['index'].toString())];
    return toEnum<Orientation>(Orientation.values, 'orientation', map);
  }
}

extension BrightnessExtension on Brightness {
  Map<String, Object> toMap() {
    return {
      'brightness': describeEnum(this),
    };
  }

  static Brightness fromMap(Map<String, Object> map) {
    // return Orientation.values[int.parse(map['index'].toString())];
    return toEnum<Brightness>(Brightness.values, 'brightness', map);
  }
}

extension EnumExtension on Enum {
  Map<String, Object> toMap() {
    return {
      'value': describeEnum(this),
    };
  }

  static T fromMap<T>(List<T> values, Map<String, Object> map) {
    // return Orientation.values[int.parse(map['index'].toString())];
    return toEnum<T>(values, 'value', map);
  }
}
