import 'package:flutter/material.dart';

import 'layer.dart';
import 'layer_descriptor.dart';

// enum LayerContainerState {
//   hidden,
//   visible,
//   dirty,
// }

class LayerController<T extends Enum> extends ChangeNotifier {
  final List<Layer<T>> _layers = [];

  LayerController({List<Layer<T>>? layers}) {
    if (layers != null) {
      _layers.addAll(layers);
    }
  }

  void addLayer(Layer<T> layer) {
    _layers.add(layer);
    notifyListeners();
  }

  void addLayers(List<Layer<T>> layers) {
    _layers.addAll(layers);
    notifyListeners();
  }

  void removeLayer(Layer<T> layer) {
    _layers.remove(layer);
    notifyListeners();
  }

  List<Layer<T>> getLayers() {
    return _layers; //.toList();
  }

  Layer<T> getLayer(T position) {
    return _layers.firstWhere((element) => element.position == position);
  }

  void show(T key) {
    final builder = getBuilder(key);
    if (builder != null) {
      builder.visible = true;
      // builder.state = LayerContainerState.visible;
      notifyListeners();
    }
  }

  void hide(T key) {
    final builder = getBuilder(key);
    if (builder != null) {
      builder.visible = false;
      // builder.state = LayerContainerState.hidden;
      notifyListeners();
    }
  }

  // void markDirty(T key) {
  //   final builder = getBuilder(key);
  //   if (builder != null) {
  //     builder.state = builder.state == LayerContainerState.dirty ? LayerContainerState.visible : LayerContainerState.dirty;
  //     notifyListeners();
  //   }
  // }

  LayerDescriptor<T>? getBuilder(T key) {
    for (var layer in _layers) {
      for (var builder in layer.layers) {
        if (builder.key == key) {
          return builder;
        }
      }
    }
  }

  updateListeners() {
    notifyListeners();
  }

  void changeVisibility(T key, bool visible) {
    getBuilder(key)?.visible = visible;
    notifyListeners();
  }
}

// class SimulatorContainerController extends ChangeNotifier {
//   final List<Widget> _layers = [];

//   SimulatorContainerController({List<Widget>? layers}) {
//     if (layers != null) {
//       _layers.addAll(layers);
//     }
//   }

//   void addLayer(Widget layer) {
//     _layers.add(layer);
//     notifyListeners();
//   }

//   void removeLayer(Widget layer) {
//     _layers.remove(layer);
//     notifyListeners();
//   }

//   List<Widget> getLayer() {
//     return _layers.toList();
//   }
// }
