import 'package:flutter/material.dart';

import '../screen/screen.dart';

void isNotNull<T>(T target, T? value) {
  if (value != null) {
    target = value;
  }
}

class ResponsiveBuilder extends StatelessWidget {
  final WidgetBuilder? xlargeScreen;
  final WidgetBuilder? largeScreen;
  final WidgetBuilder? mediumScreen;
  final WidgetBuilder? smallScreen;
  final WidgetBuilder? xsmallScreen;
  late final WidgetBuilder _fallback;

  ResponsiveBuilder({
    Key? key,
    this.xlargeScreen,
    this.largeScreen,
    this.mediumScreen,
    this.smallScreen,
    this.xsmallScreen,
    WidgetBuilder? fallback,
  }) : super(key: key) {
    _fallback = fallback ?? (_) => const SizedBox.shrink();
  }

  factory ResponsiveBuilder.upto({
    WidgetBuilder? xlargeScreen,
    WidgetBuilder? largeScreen,
    WidgetBuilder? mediumScreen,
    WidgetBuilder? smallScreen,
    // WidgetBuilder? xsmallScreen,
    WidgetBuilder? fallback,
  }) {
    WidgetBuilder? _xlargeScreen;
    WidgetBuilder? _largeScreen;
    WidgetBuilder? _mediumScreen;
    WidgetBuilder? _smallScreen;
    WidgetBuilder? _xsmallScreen;
    WidgetBuilder? _fallback = fallback;

    if (xlargeScreen != null) {
      _xsmallScreen = xlargeScreen;
      _smallScreen = xlargeScreen;
      _mediumScreen = xlargeScreen;
      _largeScreen = xlargeScreen;
      _xlargeScreen = xlargeScreen;
    }

    if (largeScreen != null) {
      _xsmallScreen = largeScreen;
      _smallScreen = largeScreen;
      _mediumScreen = largeScreen;
      _largeScreen = largeScreen;
    }

    if (mediumScreen != null) {
      _xsmallScreen = mediumScreen;
      _smallScreen = mediumScreen;
      _mediumScreen = mediumScreen;
    }

    if (smallScreen != null) {
      _xsmallScreen = smallScreen;
      _smallScreen = smallScreen;
    }

    return ResponsiveBuilder(
      xsmallScreen: _xsmallScreen,
      smallScreen: _smallScreen,
      mediumScreen: _mediumScreen,
      largeScreen: _largeScreen,
      xlargeScreen: _xlargeScreen,
      fallback: _fallback,
    );
  }

  factory ResponsiveBuilder.from(
      // WidgetBuilder? xlargeScreen,
      {
    WidgetBuilder? largeScreen,
    WidgetBuilder? mediumScreen,
    WidgetBuilder? smallScreen,
    WidgetBuilder? fallback,
    WidgetBuilder? xsmallScreen,
  }) {
    WidgetBuilder? _xlargeScreen;
    WidgetBuilder? _largeScreen;
    WidgetBuilder? _mediumScreen;
    WidgetBuilder? _smallScreen;
    WidgetBuilder? _xsmallScreen;
    WidgetBuilder? _fallback = fallback;

    if (xsmallScreen != null) {
      _xsmallScreen = xsmallScreen;
      _smallScreen = xsmallScreen;
      _mediumScreen = xsmallScreen;
      _largeScreen = xsmallScreen;
      _xlargeScreen = xsmallScreen;
    }

    if (smallScreen != null) {
      _smallScreen = smallScreen;
      _mediumScreen = smallScreen;
      _largeScreen = smallScreen;
      _xlargeScreen = smallScreen;
    }

    if (mediumScreen != null) {
      _mediumScreen = mediumScreen;
      _largeScreen = mediumScreen;
      _xlargeScreen = mediumScreen;
    }

    if (largeScreen != null) {
      _largeScreen = largeScreen;
      _xlargeScreen = largeScreen;
    }

    return ResponsiveBuilder(
      xsmallScreen: _xsmallScreen,
      smallScreen: _smallScreen,
      mediumScreen: _mediumScreen,
      largeScreen: _largeScreen,
      xlargeScreen: _xlargeScreen,
      fallback: _fallback,
    );
  }

  @override
  Widget build(BuildContext context) {
    // return LayoutBuilder(builder: (context, constraints) {
    final responsive = Screen.of(context);

    switch (responsive.screenSize) {
      case ScreenSize.xlarge:
        final builder = xlargeScreen ?? _fallback;
        return builder(context);

      case ScreenSize.large:
        final builder = largeScreen ?? _fallback;
        return builder(context);

      case ScreenSize.medium:
        final builder = mediumScreen ?? _fallback;
        return builder(context);

      case ScreenSize.small:
        final builder = smallScreen ?? _fallback;
        return builder(context);

      case ScreenSize.xsmall:
        final builder = xsmallScreen ?? _fallback;
        return builder(context);

      default:
        final builder = _fallback;
        return builder(context);
    }
  }
}
  // @override
  // Widget build(BuildContext context) {
  //   return LayoutBuilder(builder: (context, constraints) {
  //     if (Responsive.isLargeScreen(context)) {
  //       final builder = largeScreen ?? mediumScreen ?? smallScreen ?? _fallback;
  //       return builder(context);
  //     } else if (Responsive.isSmallScreen(context)) {
  //       final builder = smallScreen ?? _fallback;
  //       return builder(context);
  //     } else {
  //       final builder = mediumScreen ?? smallScreen ?? _fallback;
  //       return builder(context);
  //     }
  //   });
  // }

