import 'package:flutter/material.dart';

import '../screen/screen.dart';

class ResponsiveValue<T> {
  final T? xlarge;
  final T? large;
  final T? medium;
  final T? small;
  final T? xsmall;
  final T? fallback;

  ResponsiveValue({
    this.xlarge,
    this.large,
    this.medium,
    this.small,
    this.xsmall,
    this.fallback,
    bool allowNull = false,
  }) {
    if (!allowNull) {
      assert((xsmall != null || fallback != null) &&
          (small != null || fallback != null) &&
          (medium != null || fallback != null) &&
          (large != null || fallback != null) &&
          (xlarge != null || fallback != null));
    }
  }

  factory ResponsiveValue.upto({
    bool allowNull = false,
    T? xlarge,
    T? large,
    T? medium,
    T? small,
    // T? xsmall,
    T? fallback,
  }) {
    T? _xlarge;
    T? _large;
    T? _medium;
    T? _small;
    T? _xsmall;

    if (xlarge != null) {
      _xsmall = xlarge;
      _small = xlarge;
      _medium = xlarge;
      _large = xlarge;
      _xlarge = xlarge;
    }

    if (large != null) {
      _xsmall = large;
      _small = large;
      _medium = large;
      _large = large;
    }

    if (medium != null) {
      _xsmall = medium;
      _small = medium;
      _medium = medium;
    }

    if (small != null) {
      _xsmall = small;
      _small = small;
    }

    return ResponsiveValue(
      allowNull: allowNull,
      xsmall: _xsmall,
      small: _small,
      medium: _medium,
      large: _large,
      xlarge: _xlarge,
      fallback: fallback,
    );
  }

  factory ResponsiveValue.from(
      // T? xlarge,
      {
    bool allowNull = false,
    T? large,
    T? medium,
    T? small,
    T? xsmall,
    T? fallback,
  }) {
    T? _xlarge;
    T? _large;
    T? _medium;
    T? _small;
    T? _xsmall;

    if (xsmall != null) {
      _xsmall = xsmall;
      _small = xsmall;
      _medium = xsmall;
      _large = xsmall;
      _xlarge = xsmall;
    }

    if (small != null) {
      _small = small;
      _medium = small;
      _large = small;
      _xlarge = small;
    }

    if (medium != null) {
      _medium = medium;
      _large = medium;
      _xlarge = medium;
    }

    if (large != null) {
      _large = large;
      _xlarge = large;
    }

    return ResponsiveValue(
      allowNull: allowNull,
      xsmall: _xsmall,
      small: _small,
      medium: _medium,
      large: _large,
      xlarge: _xlarge,
      fallback: fallback,
    );
  }

  T fromScreen(Screen screen) => _getValue(screen)!;

  T value(BuildContext context) => _getValue(Screen.of(context))!;

  T? nullableValue(BuildContext context) => _getValue(Screen.of(context));

  T? _getValue(Screen screen) {
    switch (screen.screenSize) {
      case ScreenSize.xlarge:
        return xlarge ?? fallback;
      case ScreenSize.large:
        return large ?? fallback;
      case ScreenSize.medium:
        return medium ?? fallback;
      case ScreenSize.small:
        return small ?? fallback;
      case ScreenSize.xsmall:
        return xsmall ?? fallback;
      default:
        return fallback;
    }
  }
}
