import 'package:dotup_dart_utils/dotup_dart_utils.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

class ScrollWheel<T> extends StatelessWidget {
  final List<T> items;
  late final DelayedValue<T> _delayedValue;
  late final TextStyle? textStyle;
  final Color? color;
  final double itemExtent;
  final double magnification;
  final bool useMagnifier;
  final double diameterRatio;
  final double width;
  final double height;

  ScrollWheel({
    Key? key,
    required this.items,
    this.textStyle,
    this.color,
    this.itemExtent = 20,
    this.magnification = 1.2,
    this.useMagnifier = true,
    this.diameterRatio = RenderListWheelViewport.defaultDiameterRatio,
    required this.width,
    this.height = 60,
    Duration? notificationDelay,
    required ValueSetter<T> onChange,
  }) : super(key: key) {
    notificationDelay ??= Duration(milliseconds: 100);
    _delayedValue = DelayedValue<T>(delay: notificationDelay, callback: onChange);
  }

  Widget build(BuildContext context) {
    final style = textStyle ?? DefaultTextStyle.of(context).style.copyWith(color: color);

    return Container(
      width: width,
      height: height,
      child: ListWheelScrollView(
        // controller: scrollController,
        itemExtent: itemExtent,

        children: items.map(
          (e) {
            return Text(e.toString(), style: style);
          },
        ).toList(),

        magnification: magnification,
        useMagnifier: useMagnifier,
        physics: FixedExtentScrollPhysics(),
        diameterRatio: diameterRatio,
        squeeze: 1,
        onSelectedItemChanged: (index) => _delayedValue.update(items[index]),
      ),
    );
  }
}
