import 'package:flutter/material.dart';

class Section extends StatelessWidget {
  Section({
    Key? key,
    this.header,
    required this.children,
    this.footer,
    this.crossAxisAlignment = CrossAxisAlignment.start,
    EdgeInsetsGeometry? margin,
    this.elevation,
    this.dividerColor,
    this.divide = false,
    this.shape = const RoundedRectangleBorder(
      side: BorderSide(color: Colors.black26, width: 1),
      borderRadius: BorderRadius.zero,
    ),
  }) : super(key: key) {
    this.margin = margin ?? EdgeInsets.fromLTRB(0, 0, 0, DEFAULT_CONTENT_PADDING);
    // this.contentPadding = headerPadding ?? EdgeInsets.fromLTRB(0, 0, 0, DEFAULT_CONTENT_PADDING);
  }

  factory Section.divide({
    Key? key,
    Widget? header,
    Widget? footer,
    required List<Widget> children,
    CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start,
    EdgeInsetsGeometry? margin,
    double? elevation,
    Color? dividerColor,
    ShapeBorder? shape,
  }) {
    return Section(
      children: children,
      crossAxisAlignment: crossAxisAlignment,
      divide: true,
      dividerColor: dividerColor,
      elevation: elevation,
      footer: footer,
      header: header,
      key: key,
      margin: margin,
      shape: shape,
    );
  }

  // ignore: non_constant_identifier_names
  static double DEFAULT_CONTENT_PADDING = 10.0;

  final Widget? header;
  final Widget? footer;
  final List<Widget> children;
  final CrossAxisAlignment crossAxisAlignment;
  late final EdgeInsetsGeometry margin;
  final double? elevation;
  final Color? dividerColor;
  final ShapeBorder? shape;
  final bool divide;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin,
      child: Column(
        crossAxisAlignment: crossAxisAlignment,
        children: [
          if (header != null) header!,
          Card(
            margin: EdgeInsets.zero,
            elevation: elevation,
            shape: shape,
            child: Column(
              crossAxisAlignment: crossAxisAlignment,
              children: divide
                  ? ListTile.divideTiles(
                      context: context,
                      color: dividerColor,
                      tiles: children,
                    ).toList()
                  : children,
            ),
          ),
          if (footer != null) footer!,
        ],
      ),
    );
  }
}
