import 'package:flutter/material.dart';

class SectionGroupWidget<T> {
  final T value;
  final Widget child;
  final Widget? icon;
  SectionGroupWidget({required this.value, required this.child, this.icon});
}

class SectionGroup<T> extends StatelessWidget {
  final Widget? header;
  final Widget? footer;
  final List<SectionGroupWidget> children;
  final CrossAxisAlignment crossAxisAlignment;
  late final EdgeInsetsGeometry margin;
  late final EdgeInsetsGeometry contentPadding;
  final double? elevation;
  final Color? dividerColor;

  final T? groupValue;
  final ValueChanged<T?>? onChanged;

  // ignore: non_constant_identifier_names
  static double DEFAULT_CONTENT_PADDING = 10.0;

  SectionGroup({
    Key? key,
    this.header,
    required this.groupValue,
    required this.onChanged,
    required this.children,
    this.footer,
    this.crossAxisAlignment = CrossAxisAlignment.start,
    EdgeInsets? margin,
    EdgeInsets? headerPadding,
    this.elevation,
    this.dividerColor,
  }) : super(key: key) {
    this.margin = margin ?? EdgeInsets.fromLTRB(0, 0, 0, DEFAULT_CONTENT_PADDING);
    this.contentPadding = headerPadding ?? EdgeInsets.fromLTRB(0, 0, 0, DEFAULT_CONTENT_PADDING);
  }

  @override
  Widget build(BuildContext context) {
    final useIcons = children.any((element) => element.icon != null);

    return Padding(
      padding: margin,
      child: Column(
        crossAxisAlignment: crossAxisAlignment,
        children: [
          if (header != null) header!,
          Card(
            margin: EdgeInsets.zero,
            elevation: elevation,
            child: Column(
              crossAxisAlignment: crossAxisAlignment,
              children: [
                ...children.map((e) {
                  if (useIcons) {
                    return ListTile(
                      enabled: e.value != groupValue,
                      trailing: e.icon,
                      onTap: () => onChanged?.call(e.value),
                      title: e.child,
                      // controlAffinity: ListTileControlAffinity.trailing,
                    );
                  } else {
                    return RadioListTile<T>(
                      value: e.value,
                      groupValue: groupValue,
                      onChanged: onChanged,
                      title: e.child,
                      controlAffinity: ListTileControlAffinity.trailing,
                    );
                  }
                })
              ],
            ),
          ),
          if (footer != null) footer!,
        ],
      ),
    );
  }
}
