import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:mockito/mockito.dart';

class MockBuildContext extends Mock implements BuildContext {}

void main() {
  Future<BuildContext> _getBuildContext(WidgetTester tester) async {
    await tester.pumpWidget(MaterialApp(home: Material(child: Container())));
    final BuildContext context = tester.element(find.byType(Container));
    return context;
  }

  testWidgets('from: Returns 1 from xsmall', (WidgetTester tester) async {
    final context = await _getBuildContext(tester);
    final value = ResponsiveValue.from(xsmall: 1).value(context);

    expect(value, 1);
  });

  testWidgets('upto: Returns 2 up to xlarge', (WidgetTester tester) async {
    final context = await _getBuildContext(tester);
    final r = ResponsiveValue.upto(xlarge: 2);

    expect(r.value(context), 2);
    expect(r.xlarge, 2);
    expect(r.large, 2);
    expect(r.medium, 2);
    expect(r.small, 2);
    expect(r.xsmall, 2);
    expect(r.fallback, null);
  });

  testWidgets('upto: 3 to medium, 4 to xlarge', (WidgetTester tester) async {
    final r = ResponsiveValue.upto(
      medium: 3,
      xlarge: 4,
    );

    // The screen size is unknown in test environment
    // expect(r.value(context), 3);

    expect(r.xlarge, 4);
    expect(r.large, 4);
    expect(r.medium, 3);
    expect(r.small, 3);
    expect(r.xsmall, 3);
    expect(r.fallback, null);
  });
}
